#!/bin/sh

# Win32 PostGIS for PostgreSQL build script written by Mark Cave-Ayland
# Copyright 2006

# The dcmms directory should be copied into the postgis-1.x.x directory created
# by untarring the postgis-1.x.x.tar.gz file.
#
# IMPORTANT:
# Before running this script, first apply any patches in the patches/ subdirectory
# to the source tree. If any of the patches make changes to configure.in, you will
# also need to run ./autogen.sh supplied with PostGIS before running this script.


# Installation directories - should be the same as those passed as
# configure --prefix=<DIR> at build time
PGSQL_DIR=/home/mca/pg80/rel-8.0.8
GEOS_DIR=/home/mca/geos/rel-2.2.3
PROJ_DIR=/home/mca/proj/rel-4.5.0

# Directory of running PostgreSQL instance
PGSQL_RUNDIR="/c/progra~1/postgr~1/8.0"

# PostGIS JDBC version and path to the PostgreSQL driver JAR file
JDBC_VERSION=1.2.0
JDBC_PGJAR="/c/Program Files/PostgreSQL/8.1/jdbc/postgresql-8.1-405.jdbc2.jar"

# Connection details for regression test database
REG_PGUSER=pg80
REG_PGPORT=5480

# Directory containing pre-compiled libxslt/xsltproc
LIBXSLT=/home/mca/xslt/bin


# Save current directory
pushd .
cd ..

# First build PostGIS with a reference to ICONV and execute regression tests
echo "#### Building PostGIS..."
pushd .
PATH=$LIBXSLT:$PATH ./configure --with-pgsql=$PGSQL_DIR/bin/pg_config.exe --with-geos=$GEOS_DIR/bin/geos-config --with-proj=$PROJ_DIR

# Bug report from Akio Takubo: stripped versions of liblwgeom.dll do not load correctly under WinXP SP2
# Japanese edition. Therefore we manually remove the debug (-g) option from the resulting Makefile in
# order to keep the size of the resulting executable reasonable.
cp lwgeom/Makefile lwgeom/Makefile.tmp
cat lwgeom/Makefile.tmp | sed 's/\-Wall \-g/\-Wall/g' > lwgeom/Makefile

# Execute make
CFLAGS="-I$PGSQL_DIR/include -L$PG_SQLDIR/lib" make

# Also build the documentation
echo "#### Building HTML documentation..."
cd doc
PATH=$LIBXSLT:$PATH make
cd ..

echo "#### Running regression tests..."
cp $GEOS_DIR/bin/libgeos-2.dll "$PGSQL_RUNDIR/bin"
cp $GEOS_DIR/bin/libgeos_c-1.dll "$PGSQL_RUNDIR/bin"
cp $PROJ_DIR/lib/libproj.dll "$PGSQL_RUNDIR/bin"
PATH=$PGSQL_RUNDIR/bin:$PGSQL_RUNDIR/lib:$PATH PGUSER=$REG_PGUSER PGPORT=$REG_PGPORT make test
rm "$PGSQL_RUNDIR/bin/libproj.dll"
rm "$PGSQL_RUNDIR/bin/libgeos_c-1.dll"
rm "$PGSQL_RUNDIR/bin/libgeos-2.dll"

echo "#### Building topology SQL file..."
cd topology
make
popd

# Build the JDBC drivers
echo "#### Building PostGIS JDBC drivers..."
pushd .
cd java/jdbc
CLASSPATH=$JDBC_PGJAR make
popd

# Copy the files we want to a distribution directory
echo "#### Generating Win32 dist directory..."
rm -rf win32dist
mkdir win32dist
cd win32dist

## bin directory
mkdir bin

cp $GEOS_DIR/bin/libgeos-2.dll bin
cp $GEOS_DIR/bin/libgeos_c-1.dll bin
cp $PROJ_DIR/lib/libproj.dll bin

cp ../loader/pgsql2shp.exe bin
cp ../loader/shp2pgsql.exe bin

## lib directory
mkdir lib


## doc directory
mkdir -p doc/contrib/html/postgis

cp ../README.postgis doc/contrib
cp ../loader/README.shp2pgsql doc/contrib
cp ../loader/README.pgsql2shp doc/contrib
cp ../doc/html/*.html doc/contrib/html/postgis
cp ../doc/html/style.css doc/contrib/html/postgis

## share directory
mkdir -p share/contrib/postgis

cp ../lwpostgis.sql share/contrib
cp ../spatial_ref_sys.sql share/contrib

mkdir -p share/contrib/postgis/utils

cp ../utils/create_undef.pl share/contrib/postgis/utils
cp ../utils/postgis_restore.pl share/contrib/postgis/utils
cp ../utils/postgis_proc_upgrade.pl share/contrib/postgis/utils
cp ../lwpostgis_upgrade.sql share/contrib/postgis

mkdir -p share/contrib/postgis/topology
cp ../topology/README share/contrib/postgis/topology/
cp ../topology/topology.sql share/contrib/postgis/topology/

## jdbc directory
mkdir jdbc

cp ../java/jdbc/postgis_$JDBC_VERSION.jar jdbc


# Strip any DLL and EXE files in the distribution tree
find -name *.dll | xargs strip
find -name *.exe | xargs strip

# Finally copy the unstripped liblwgeom.dll into the distribution tree
cp ../lwgeom/liblwgeom.dll lib


# Pop directory
popd

# Generate the .nsh include files by scanning the directories
echo "#### Generating NSIS file lists for win32dist distribution directory..."
./geninputfiles.sh > inputfiles.nsh
./genuninstallfiles.sh > uninstallfiles.nsh

# Completed
echo "#### Done. The complete distribution can be found in the ../win32dist/ directory."
